var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useState, useEffect } from 'react';
import AudioRecorder from './AudioRecorder';
export const recorderSetupError = 'There was a problem setting up the recorder';
const useAudioRecorder = (fileName) => {
    const [recorder, setRecorder] = useState({});
    const [status, setStatus] = useState({ loading: true });
    const [error, setError] = useState();
    useEffect(() => {
        function createRecorder() {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    const nativeRecorder = new AudioRecorder(fileName, setStatus);
                    // wait for player to be created before returning
                    yield nativeRecorder.prepare();
                    if (nativeRecorder.status.ready) {
                        setRecorder(nativeRecorder);
                    }
                    if (!nativeRecorder.status.ready) {
                        setError(recorderSetupError);
                    }
                }
                catch (err) {
                    setError(recorderSetupError);
                }
            });
        }
        if (!status.ready) {
            createRecorder();
        }
    }, [status]);
    const recorderController = {
        status,
        fileName: recorder.fileName,
        toggleRecording: recorder.toggleRecording
    };
    return [recorderController, error];
};
export default useAudioRecorder;
